==> sped-1.35.26.tar.gz: sped-1.35.26/pythonsped/efd/layout_12.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from bloco_d import bloco_d as efd_bloco_d
from bloco_c import bloco_c as efd_bloco_c
from bloco_1 import bloco_1 as efd_bloco_1
import layout_11
import datetime

# Ato COTEPE/ICMS item 3.1.1 - Tabela Versao do Leiaute
_obrigatoriedade_ = '01/01/2018'
_codigo_ = '012'  # layout_12
_versao_ = '111'


class bloco_0(layout_11.bloco_0):
    pass


class bloco_1(layout_11.bloco_1):
    pass


class bloco_c(layout_11.bloco_c):
    pass


class bloco_e(layout_11.bloco_e):
    pass


class bloco_d(efd_bloco_d):
    """Classe do Bloco D"""

    class registro_D100(efd_bloco_d.registro_D100):
        """
        REGISTRO D100: NOTA FISCAL DE SERVIÇO DE TRANSPORTE (CÓDIGO 07) E CONHECIMENTOS DE
        TRANSPORTE RODOVIÁRIO DE CARGAS (CÓDIGO 08), CONHECIMENTOS DE TRANSPORTE DE CARGAS AVULSO
        (CÓDIGO 8B), AQUAVIÁRIO DE CARGAS (CÓDIGO 09), AÉREO (CÓDIGO 10), FERROVIÁRIO DE CARGAS
        (CÓDIGO 11) E MULTIMODAL DE CARGAS (CÓDIGO 26), NOTA FISCAL DE TRANSPORTE FERROVIÁRIO DE
        CARGA ( CÓDIGO 27) E CONHECIMENTO DE TRANSPORTE ELETRÔNICO – CT-e (CÓDIGO 57).Este registro
        deve ser apresentado por todos os contribuintes adquirentes ou prestadores dos servicos que
        utilizem os documentos previstos para este registro.
        """

        # GUIA PRATICO DA EFD - Versao 2.0.22
        def __init__(self):
            super(bloco_d.registro_D100, self).__init__()
            self.layout = 12  # Layout atual
            self.fieldnames = ['REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'COD_SIT',
                               'SER', 'SUB', 'NUM_DOC', 'CHV_CTE', 'DT_DOC', 'DT_A_P', 'TP_CT_e',
                               'CHV_CTE_REF', 'VL_DOC', 'VL_DESC', 'IND_FRT', 'VL_SERV',
                               'VL_BC_ICMS', 'VL_ICMS', 'VL_NT', 'COD_INF', 'COD_CTA',
                               'COD_MUN_ORIG', 'COD_MUN_DEST']

        @property
        def registro(self):
            return self.registro

        @registro.setter
        def registro(self, value):
            self.conta_registro['bloco_d'] = self.conta_registro.get('bloco_d', 0) + 1
            self.quantidade_registros['D100'] = self.quantidade_registros.get('D100', 0) + 1
            dados = list()
            for field in self.fieldnames:
                dado = value.get(field.lower()) or ''
                if isinstance(dado, float):
                    dado = ('%.2f' % dado).replace('.', ',')
                elif isinstance(dado, datetime.date):
                    dado = dado.strftime('%d%m%Y')
                else:
                    dado = str(dado)
                dados.append(self.remove_accents(dado))
            self.processos.append('|' + '|'.join(dados) + '|\r\n')

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> sped-3.0.4.tar.gz: sped-3.0.4/pythonsped/efd/layout_12.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from .bloco_d import bloco_d as efd_bloco_d
from .bloco_c import bloco_c as efd_bloco_c
from .bloco_1 import bloco_1 as efd_bloco_1
from . import layout_11
import datetime

# Ato COTEPE/ICMS item 3.1.1 - Tabela Versao do Leiaute
_obrigatoriedade_ = '01/01/2018'
_codigo_ = '012'  # layout_12
_versao_ = '111'


class bloco_0(layout_11.bloco_0):
    pass


class bloco_1(layout_11.bloco_1):
    pass


class bloco_c(layout_11.bloco_c):
    pass


class bloco_e(layout_11.bloco_e):
    pass


class bloco_d(efd_bloco_d):
    """Classe do Bloco D"""

    class registro_D100(efd_bloco_d.registro_D100):
        """
        REGISTRO D100: NOTA FISCAL DE SERVIÇO DE TRANSPORTE (CÓDIGO 07) E CONHECIMENTOS DE
        TRANSPORTE RODOVIÁRIO DE CARGAS (CÓDIGO 08), CONHECIMENTOS DE TRANSPORTE DE CARGAS AVULSO
        (CÓDIGO 8B), AQUAVIÁRIO DE CARGAS (CÓDIGO 09), AÉREO (CÓDIGO 10), FERROVIÁRIO DE CARGAS
        (CÓDIGO 11) E MULTIMODAL DE CARGAS (CÓDIGO 26), NOTA FISCAL DE TRANSPORTE FERROVIÁRIO DE
        CARGA ( CÓDIGO 27) E CONHECIMENTO DE TRANSPORTE ELETRÔNICO – CT-e (CÓDIGO 57).Este registro
        deve ser apresentado por todos os contribuintes adquirentes ou prestadores dos servicos que
        utilizem os documentos previstos para este registro.
        """

        # GUIA PRATICO DA EFD - Versao 2.0.22
        def __init__(self):
            super(bloco_d.registro_D100, self).__init__()
            self.layout = 12  # Layout atual
            self.fieldnames = ['REG', 'IND_OPER', 'IND_EMIT', 'COD_PART', 'COD_MOD', 'COD_SIT',
                               'SER', 'SUB', 'NUM_DOC', 'CHV_CTE', 'DT_DOC', 'DT_A_P', 'TP_CT_e',
                               'CHV_CTE_REF', 'VL_DOC', 'VL_DESC', 'IND_FRT', 'VL_SERV',
                               'VL_BC_ICMS', 'VL_ICMS', 'VL_NT', 'COD_INF', 'COD_CTA',
                               'COD_MUN_ORIG', 'COD_MUN_DEST']

        @property
        def registro(self):
            return self.registro

        @registro.setter
        def registro(self, value):
            self.conta_registro['bloco_d'] = self.conta_registro.get('bloco_d', 0) + 1
            self.quantidade_registros['D100'] = self.quantidade_registros.get('D100', 0) + 1
            dados = list()
            for field in self.fieldnames:
                dado = value.get(field.lower()) or ''
                if isinstance(dado, float):
                    dado = ('%.2f' % dado).replace('.', ',')
                elif isinstance(dado, datetime.date):
                    dado = dado.strftime('%d%m%Y')
                else:
                    dado = str(dado)
                dados.append(self.remove_accents(dado))
            self.processos.append('|' + '|'.join(dados) + '|\r\n')

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
